@@ -44,6 +44,7 @@ import org.apache.empire.data.Column;
 import org.apache.empire.data.DataType;
 import org.apache.empire.exceptions.InvalidArgumentException;
 import org.apache.empire.exceptions.UnexpectedReturnValueException;
+import org.apache.empire.jsf2.utils.TagStyleClass;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -99,15 +100,15 @@ public class TextInputControl extends InputControl
         compList.add(input);
         // add unit
         String unit = getUnitString(ii);
-        if (StringUtils.isNotEmpty(unit))
+        if (StringUtils.isNotEmpty(unit) && !hasFormatOption(ii, "nounit"))
         {   // add the unit
-            compList.add(createUnitLabel("eUnit", ii, unit));
+            compList.add(createUnitLabel(TagStyleClass.UNIT.get(), ii, unit));
         }
         // add hint
         String hint = StringUtils.toString(ii.getAttribute("hint"));
         if (StringUtils.isNotEmpty(hint) && !ii.isDisabled())
         {   // add the hint (if not an empty string!)
-            compList.add(createUnitLabel("eInputHint", ii, hint));
+            compList.add(createUnitLabel(TagStyleClass.INPUT_HINT.get(), ii, hint));
         }
         // update
         updateInputState(compList, ii, context, context.getCurrentPhaseId());
@@ -136,9 +137,9 @@ public class TextInputControl extends InputControl
             */
         }
         // required
-        addRemoveStyle(input, InputControl.STYLECLASS_REQUIRED, ii.isRequired());
+        addRemoveStyle(input, TagStyleClass.INPUT_REQ, ii.isRequired());
         // modified
-        addRemoveStyle(input, InputControl.STYLECLASS_MODIFIED, ii.isModified());
+        addRemoveStyle(input, TagStyleClass.INPUT_MOD, ii.isModified());
 
         // disabled
         DisabledType disabled = ii.getDisabled();
@@ -169,6 +170,7 @@ public class TextInputControl extends InputControl
         */
         span.getAttributes().put("styleClass", tagStyle);
         span.getChildren().add(text);
+        // done 
         return span;
     }
 
@@ -366,7 +368,7 @@ public class TextInputControl extends InputControl
         writer.append(text);
         // unit?
         String unit = getUnitString(vi);
-        if (StringUtils.isNotEmpty(unit))
+        if (StringUtils.isNotEmpty(unit) && !hasFormatOption(vi, "nounit"))
         { // append unit
             writer.append(" ");
             writer.append(unit);
@@ -439,7 +441,7 @@ public class TextInputControl extends InputControl
         Column col = ii.getColumn();
         // cast to DBTableColumn 
         DataType type = col.getDataType();
-        if (type == DataType.CHAR || type == DataType.VARCHAR || type == DataType.TEXT)
+        if (type == DataType.CHAR || type == DataType.VARCHAR)
             return (int) Math.round(col.getSize());
         if (type == DataType.AUTOINC || type == DataType.INTEGER)
             return 10;
