@@ -321,7 +321,7 @@ public abstract class DBDatabase extends DBObject
      * For general use of Prepared Statements please use DBContext.createCommand()
      * However statement parameters can always be manually declared using cmd.addCmdParam();   
      *    
-     * @param preparedStatementsEnabled
+     * @param autoPrepareStmt flag whether to automatically convert literal values to prepared statement params
      */
     public void setPreparedStatementsEnabled(boolean autoPrepareStmt)
     {
@@ -507,38 +507,38 @@ public abstract class DBDatabase extends DBObject
      * and database link postfix (if any).
      * to the string buffer supplied
      * 
-     * @param buf the string buffer to which to append the qualified object name
+     * @param sql the SQL Builder to which to append the qualified object name
      * @param name the object's name
      * @param quoteName use quotes or not. If null detectQuoteName() is called
      */
-    public void appendQualifiedName(StringBuilder buf, String name, Boolean quoteName)
+    public void appendQualifiedName(DBSQLBuilder sql, String name, Boolean quoteName)
     {
         // Schema
         if (schema != null)
         { // Add Schema
-            buf.append(schema);
-            buf.append(".");
+            sql.append(schema);
+            sql.append(".");
         }
         // Check dbms
         if (dbms==null)
         {   // No dbms attached!
             log.warn("No dbms attached for appending qualified name {0}.", name);
-            buf.append(name);
+            sql.append(name);
             return;
         }
         // Append the name
-        dbms.appendObjectName(buf, name, quoteName);
+        dbms.appendObjectName(sql, name, quoteName);
         // Database Link
         if (linkName!=null)
         {   // Add Link
-            buf.append(dbms.getSQLPhrase(DBSqlPhrase.SQL_DATABASE_LINK));
-            buf.append(linkName);
+            sql.append(dbms.getSQLPhrase(DBSqlPhrase.SQL_DATABASE_LINK));
+            sql.append(linkName);
         }
     }
     
     /**
      * Returns the java class type for a given dataType
-     * @param type the data type
+     * @param expr the column expression for witch to return the java type
      * @return return the java class used for storing values of this dataType 
      */
     public Class<?> getColumnJavaType(DBColumnExpr expr)
@@ -816,7 +816,7 @@ public abstract class DBDatabase extends DBObject
 
     /**
      * removes a relation from the list of relations
-     * @param name
+     * @param relation the relation to remove
      */
     public void removeRelation(DBRelation relation)
     {
@@ -829,7 +829,7 @@ public abstract class DBDatabase extends DBObject
     /**
      * Returns the relations which have been defined in the database.
      * 
-     * @return db relations.
+     * @return the list of relations.
      */
     public List<DBRelation> getRelations()
     {
@@ -930,11 +930,11 @@ public abstract class DBDatabase extends DBObject
     /**
      * Creates a new Command object for this database
      * 
+     * Deprecated instead use context.createCommand();
+     * 
      * @return the command object.
-     *
-     * @Deprecated use context.createCommand();
      */
-    public final DBCommand createCommand()
+    public DBCommand createCommand()
     {
         checkOpen(); 
         // For compatiblity with 2.x dont use isPreparedStatementsEnabled() 
@@ -1126,30 +1126,19 @@ public abstract class DBDatabase extends DBObject
         // Check Range
         Object min = column.getAttribute(Column.COLATTR_MINVALUE);
         Object max = column.getAttribute(Column.COLATTR_MAXVALUE);
-        if (min!=null && max!=null)
-        {   // Check Range
-            long minVal = ObjectUtils.getLong(min);
-            long maxVal = ObjectUtils.getLong(max);
-            if (n.longValue()<minVal || n.longValue()>maxVal)
-            {   // Out of Range
-                throw new FieldValueOutOfRangeException(column, minVal, maxVal);
-            }
+        boolean belowMin = (min instanceof Number) ? ObjectUtils.compare(n, min)<0 : false;
+        boolean aboveMax = (max instanceof Number) ? ObjectUtils.compare(n, max)>0 : false;
+        if (belowMin && aboveMax)
+        {   // Out of Range
+            throw new FieldValueOutOfRangeException(column, (Number)min, (Number)max);
         }
-        else if (min!=null)
+        else if (belowMin)
         {   // Check Min Value
-            long minVal = ObjectUtils.getLong(min);
-            if (n.longValue()<minVal)
-            {   // Out of Range
-                throw new FieldValueOutOfRangeException(column, minVal, false);
-            }
+            throw new FieldValueOutOfRangeException(column, (Number)min, false);
         }
-        else if (max!=null)
+        else if (aboveMax)
         {   // Check Max Value
-            long maxVal = ObjectUtils.getLong(max);
-            if (n.longValue()>maxVal)
-            {   // Out of Range
-                throw new FieldValueOutOfRangeException(column, maxVal, true);
-            }
+            throw new FieldValueOutOfRangeException(column, (Number)max, true);
         }
         // Check overall
         if (type==DataType.DECIMAL)
@@ -1178,12 +1167,12 @@ public abstract class DBDatabase extends DBObject
     
     /**
      * Creates a case column expression
-     * "case when <condition> then <trueValue> else <falseValue> end"
+     * in the form "case when [condition] then [trueValue] else [falseValue] end"
      * This is a helper function to simplify client usage
-     * @param condition
+     * @param condition the compare expression
      * @param trueValue the value to select if the condition is true
      * @param falseValue the value to select if the condition is false
-     * @return an sql case expression
+     * @return the case expression
      */
     public DBColumnExpr caseWhen(DBCompareExpr condition, Object trueValue, Object falseValue)
     {
@@ -1200,7 +1189,7 @@ public abstract class DBDatabase extends DBObject
 
     /**
      * Creates a case column expression that check whether a column or column expression is null
-     * "case when <condition> is null then <trueValue> else <falseValue> end"
+     * "case when [condition] is null then [trueValue] else [falseValue] end"
      * This is a helper function to simplify client usage
      * @param expr a column or column expression
      * @param trueValue the value to select if the condition is true
