@@ -33,13 +33,14 @@ import org.apache.empire.db.DBDDLGenerator.DDLActionType;
 import org.apache.empire.db.DBDatabase;
 import org.apache.empire.db.DBObject;
 import org.apache.empire.db.DBRowSet;
+import org.apache.empire.db.DBSQLBuilder;
 import org.apache.empire.db.DBSQLScript;
 import org.apache.empire.db.DBTable;
 import org.apache.empire.db.DBTableColumn;
 import org.apache.empire.db.exceptions.EmpireSQLException;
+import org.apache.empire.dbms.DBMSFeature;
 import org.apache.empire.dbms.DBMSHandler;
 import org.apache.empire.dbms.DBMSHandlerBase;
-import org.apache.empire.dbms.DBMSFeature;
 import org.apache.empire.dbms.DBSqlPhrase;
 import org.apache.empire.exceptions.NotSupportedException;
 import org.slf4j.Logger;
@@ -66,9 +67,9 @@ public class DBMSHandlerMySQL extends DBMSHandlerBase
         protected int limit = -1;
         protected int skip  = -1;
         
-        public DBCommandMySQL(boolean autoPrepareStmt)
+        public DBCommandMySQL(DBMSHandlerMySQL dbms, boolean autoPrepareStmt)
         {
-            super(autoPrepareStmt);
+            super(dbms, autoPrepareStmt);
         }
         
         @Override
@@ -93,33 +94,66 @@ public class DBMSHandlerMySQL extends DBMSHandlerBase
         }
         
         @Override
-        public void getSelect(StringBuilder buf)
+        public void getSelect(DBSQLBuilder sql)
         {   // call base class
-            super.getSelect(buf);
+            super.getSelect(sql);
             // add limit and offset
             if (limit>=0)
-            {   buf.append("\r\nLIMIT ");
-                buf.append(String.valueOf(limit));
+            {   sql.append("\r\nLIMIT ");
+                sql.append(String.valueOf(limit));
                 // Offset
                 if (skip>=0) 
-                {   buf.append(" OFFSET ");
-                    buf.append(String.valueOf(skip));
+                {   sql.append(" OFFSET ");
+                    sql.append(String.valueOf(skip));
                 }    
             }
         }
         
-        /**
-         * Creates an MySQL specific delete statement.
-         * @return the delete SQL-Command
-         */
         @Override
-        protected void addDeleteWithJoins(StringBuilder buf, DBRowSet table)
+        protected void addDeleteWithJoins(DBSQLBuilder sql, DBRowSet table)
         {
             // DELETE with Multiple-Table Syntax
             // http://dev.mysql.com/doc/refman/5.7/en/delete.html
-            buf.append(table.getAlias());
-            addFrom(buf);
-            addWhere(buf);
+            sql.append(table.getAlias());
+            addFrom(sql);
+            addWhere(sql);
+        }
+    }
+    
+    /**
+     * Provides a DBSQLBuilder implementation for MySQL
+     */
+    public static class DBSQLBuilderMySQL extends DBSQLBuilder 
+    {
+        public DBSQLBuilderMySQL(DBMSHandlerMySQL dbms)
+        {
+            super(dbms);
+        }
+        
+        @Override
+        protected void escapeAndAppendLiteral(String value)
+        {
+            if (value.indexOf('\'') >= 0 || value.indexOf('\\') >= 0)
+            {
+                int len = value.length();
+                for (int i = 0; i < len; i++)
+                {
+                    if (value.charAt(i) == '\'')
+                    {   // a routine to double up single quotes for SQL
+                        sql.append("''");
+                    }
+                    else if (value.charAt(i) == '\\')
+                    {   // a routine to double up backslashes for MySQL
+                        sql.append("\\\\");
+                    } 
+                    else
+                    {   // normal
+                        sql.append(value.charAt(i));
+                    }
+                }
+            } else {
+                sql.append(value);
+            }
         }
     }
     
@@ -900,7 +934,17 @@ public class DBMSHandlerMySQL extends DBMSHandlerBase
     public DBCommand createCommand(boolean autoPrepareStmt)
     {
         // create command object
-        return new DBCommandMySQL(autoPrepareStmt);
+        return new DBCommandMySQL(this, autoPrepareStmt);
+    }
+
+    /**
+     * Creates a new MySQL SQL-Builder.
+     * @return the new DBSQLBuilder object
+     */
+    @Override
+    public DBSQLBuilder createSQLBuilder()
+    {
+        return new DBSQLBuilderMySQL(this);
     }
 
     @Override
@@ -937,17 +981,17 @@ public class DBMSHandlerMySQL extends DBMSHandlerBase
                 skip  = -1;
             }
             @Override
-            public void getSelect(StringBuilder buf)
+            public void getSelect(DBSQLBuilder sql)
             {   // Prepares statement
-            	super.getSelect(buf);
+            	super.getSelect(sql);
                 // add limit and offset
                 if (limit>=0)
-                {   buf.append("\r\nLIMIT ");
-                    buf.append(String.valueOf(limit));
+                {   sql.append("\r\nLIMIT ");
+                    sql.append(String.valueOf(limit));
                     // Offset
                     if (skip>=0) 
-                    {   buf.append(" OFFSET ");
-                        buf.append(String.valueOf(skip));
+                    {   sql.append(" OFFSET ");
+                        sql.append(String.valueOf(skip));
                     }    
                 }
             }
@@ -976,7 +1020,7 @@ public class DBMSHandlerMySQL extends DBMSHandlerBase
     
     /**
      * Gets an sql phrase template for this database system.<br>
-     * @see DBMSHandler#getSQLPhrase(int)
+     * @see DBMSHandler#getSQLPhrase(DBSqlPhrase)
      * @return the phrase template
      */
     @Override
@@ -1087,7 +1131,7 @@ public class DBMSHandlerMySQL extends DBMSHandlerBase
     }
     
     /**
-     * @see DBMSHandler#getNextSequenceValue(DBDatabase, String, int, Connection)
+     * @see DBMSHandlerBase#getNextSequenceValue(DBDatabase, String, int, Connection)
      */
     @Override
     public Object getNextSequenceValue(DBDatabase db, String seqName, int minValue, Connection conn)
@@ -1104,7 +1148,7 @@ public class DBMSHandlerMySQL extends DBMSHandlerBase
     }
 
     /**
-     * @see DBMSHandler#getNextSequenceValueExpr(DBTableColumn col)
+     * @see DBMSHandlerBase#getNextSequenceValueExpr(DBTableColumn col)
      */
     @Override
     public DBColumnExpr getNextSequenceValueExpr(DBTableColumn column)
@@ -1137,33 +1181,5 @@ public class DBMSHandlerMySQL extends DBMSHandlerBase
         ddlGenerator.getDDLScript(type, dbo, script); 
     }
 
-    /** 
-     * this helper function doubles up single quotes for SQL 
-     */
-    @Override
-    protected void appendSQLTextValue(StringBuilder buf, String value)
-    {
-        if (value.indexOf('\'') >= 0 || value.indexOf('\\') >= 0)
-        {
-        	int len = value.length();
-            for (int i = 0; i < len; i++)
-            {
-                if (value.charAt(i) == '\'')
-                { // a routine to double up single quotes for SQL
-                    buf.append("''");
-                }
-                else if (value.charAt(i) == '\\')
-                { // a routine to double up backslashes for MySQL
-                	buf.append("\\\\");
-                } else
-                {
-                	buf.append(value.charAt(i));
-                }
-            }
-        } else 
-        {
-            buf.append(value);
-        }
-    }
     
 }
