@@ -34,6 +34,7 @@ import org.apache.empire.db.DBDatabase;
 import org.apache.empire.db.DBExpr;
 import org.apache.empire.db.DBObject;
 import org.apache.empire.db.DBRelation;
+import org.apache.empire.db.DBSQLBuilder;
 import org.apache.empire.db.DBSQLScript;
 import org.apache.empire.db.DBTable;
 import org.apache.empire.db.DBTableColumn;
@@ -58,16 +59,16 @@ public class DBMSHandlerMSSQL extends DBMSHandlerBase
     private static final Logger log = LoggerFactory.getLogger(DBMSHandlerMSSQL.class);
   
     /**
-     * Defines the Microsoft SQL-Server command type.
-     */ 
+     * Provides a DBCommand implementation for Microsoft SQL-Server
+     */
     public static class DBCommandMSSQL extends DBCommand
     {
         // *Deprecated* private static final long serialVersionUID = 1L;
         protected int limit = -1;
 
-        public DBCommandMSSQL(boolean autoPrepareStmt)
+        public DBCommandMSSQL(DBMSHandlerMSSQL dbms, boolean autoPrepareStmt)
     	{
-    		super(autoPrepareStmt);
+    		super(dbms, autoPrepareStmt);
     	}
         
         @Override
@@ -84,21 +85,51 @@ public class DBMSHandlerMSSQL extends DBMSHandlerBase
         }
         
         @Override
-        protected void addSelect(StringBuilder buf)
+        protected void addSelect(DBSQLBuilder sql)
         {   
             // Prepares statement
-            buf.append("SELECT ");
+            sql.append("SELECT ");
             if (selectDistinct)
-                buf.append("DISTINCT ");
+                sql.append("DISTINCT ");
             // Add limit
             if (limit>=0)
             {   // Limit
-                buf.append("TOP ");
-                buf.append(String.valueOf(limit));
-                buf.append(" ");
+                sql.append("TOP ");
+                sql.append(String.valueOf(limit));
+                sql.append(" ");
             }
             // Add Select Expressions
-            addListExpr(buf, select, CTX_ALL, ", ");
+            addListExpr(sql, select, CTX_ALL, ", ");
+        }
+    }
+    
+    /**
+     * Provides a DBSQLBuilder implementation for Microsoft SQL-Server
+     */
+    public static class DBSQLBuilderMSSQL extends DBSQLBuilder 
+    {
+        private final boolean useUnicodePrefix;
+        
+        public DBSQLBuilderMSSQL(DBMSHandlerMSSQL dbms)
+        {
+            super(dbms);
+            // init
+            this.useUnicodePrefix = dbms.useUnicodePrefix;
+        }
+        
+        @Override
+        protected void appendStringLiteral(DataType type, Object value)
+        {   // text
+            if (value==null)
+            {   append(DBSqlPhrase.SQL_NULL);
+                return;
+            }
+            String text = value.toString();
+            // for SQLSERVER utf8 support, see EMPIREDB-122
+            sql.append((useUnicodePrefix) ? "N'" : "'");
+            if (DBDatabase.EMPTY_STRING.equals(text)==false)
+                escapeAndAppendLiteral(text);
+            sql.append(TEXT_DELIMITER);
         }
     }
     
@@ -274,14 +305,23 @@ public class DBMSHandlerMSSQL extends DBMSHandlerBase
 
     /**
      * Creates a new Microsoft SQL-Server command object.
-     * 
-     * @return the new DBCommandMSSQL object
+     * @return the new DBCommand object
      */
     @Override
     public DBCommand createCommand(boolean autoPrepareStmt)
     {
         // create command object
-        return new DBCommandMSSQL(autoPrepareStmt);
+        return new DBCommandMSSQL(this, autoPrepareStmt);
+    }
+    
+    /**
+     * Creates a new Microsoft SQL-Server SQL-Builder.
+     * @return the new DBSQLBuilder object
+     */
+    @Override
+    public DBSQLBuilder createSQLBuilder()
+    {
+        return new DBSQLBuilderMSSQL(this);
     }
 
     /**
@@ -306,7 +346,7 @@ public class DBMSHandlerMSSQL extends DBMSHandlerBase
 
     /**
      * Gets an sql phrase template for this database system.<br>
-     * @see DBMSHandler#getSQLPhrase(int)
+     * @see DBMSHandler#getSQLPhrase(DBSqlPhrase)
      * @return the phrase template
      */
     @Override
@@ -395,7 +435,13 @@ public class DBMSHandlerMSSQL extends DBMSHandlerBase
         {
            case BOOL:      return "convert(bit, ?)";
            case INTEGER:   return "convert(int, ?)";
-           case DECIMAL:   return "convert(decimal, ?)";
+           case DECIMAL:
+               if (format instanceof Number)
+               {   // Format should be a float, double or BigDecimal with prec.scale
+                   return "convert(decimal("+format.toString().replace('.', ',')+"), ?)";
+               }
+               // plain
+               return "convert(decimal, ?)";
            case FLOAT:     return "convert(float, ?)";
            case DATE:      return "convert(date, ?, 111)";
            case TIME:      return "convert(time, ?)";
@@ -424,7 +470,7 @@ public class DBMSHandlerMSSQL extends DBMSHandlerBase
     }
 
     /**
-     * @see DBMSHandler#getNextSequenceValue(DBDatabase, String, int, Connection)
+     * @see DBMSHandlerBase#getNextSequenceValue(DBDatabase, String, int, Connection)
      */
     @Override
     public Object getNextSequenceValue(DBDatabase db, String seqName, int minValue, Connection conn)
@@ -441,7 +487,7 @@ public class DBMSHandlerMSSQL extends DBMSHandlerBase
     }
 
     /**
-     * @see DBMSHandler#getNextSequenceValueExpr(DBTableColumn col)
+     * @see DBMSHandlerBase#getNextSequenceValueExpr(DBTableColumn col)
      */
     @Override
     public DBColumnExpr getNextSequenceValueExpr(DBTableColumn column)
@@ -451,21 +497,6 @@ public class DBMSHandlerMSSQL extends DBMSHandlerBase
         // automatic identity management
         return null;
     }
-
-    /**
-     * @see DBMSHandler#getSQLTextString(DataType type, Object value)
-     */
-    @Override
-    protected String getSQLTextString(DataType type, Object value)
-    {
-        StringBuilder valBuf = new StringBuilder();
-        // for SQLSERVER utf8 support, see EMPIREDB-122
-        valBuf.append((useUnicodePrefix) ? "N'" : "'");
-        if (DBDatabase.EMPTY_STRING.equals(value)==false)
-            appendSQLTextValue(valBuf, value.toString());
-        valBuf.append("'");
-        return valBuf.toString();
-    }
     
     /**
      * Overridden. Returns a timestamp that is used for record updates created by the database server.
@@ -553,14 +584,14 @@ public class DBMSHandlerMSSQL extends DBMSHandlerBase
     public void appendEnableRelationStmt(DBRelation r, boolean enable, DBSQLScript script)
     {
         // ALTER TABLE {table.name} {CHECK|NOCHECK} CONSTRAINT {relation.name}
-        StringBuilder b = new StringBuilder();
-        b.append("ALTER TABLE ");
-        r.getForeignKeyTable().addSQL(b, DBExpr.CTX_FULLNAME);
-        b.append(enable ? " CHECK " : " NOCHECK ");
-        b.append("CONSTRAINT ");
-        b.append(r.getName());
+        DBSQLBuilder sql = createSQLBuilder();
+        sql.append("ALTER TABLE ");
+        r.getForeignKeyTable().addSQL(sql, DBExpr.CTX_FULLNAME);
+        sql.append(enable ? " CHECK " : " NOCHECK ");
+        sql.append("CONSTRAINT ");
+        sql.append(r.getName());
         // add
-        script.addStmt(b);
+        script.addStmt(sql);
     }
 
     /**
