@@ -18,20 +18,17 @@
  */
 package org.apache.empire.exceptions;
 
-import org.apache.empire.commons.ErrorType;
-
-public class MiscellaneousErrorException extends EmpireException
+/**
+ * MiscellaneousErrorException
+ * @deprecated use UnspecifiedErrorException
+ */
+@Deprecated
+public final class MiscellaneousErrorException extends UnspecifiedErrorException
 {
-    /**
-     * Comment for <code>serialVersionUID</code>
-     */
     private static final long serialVersionUID = 1L;
-    
-    public static final ErrorType errorType = new ErrorType("error.internal", "Internal Error: {0}");
-    
+
     public MiscellaneousErrorException(String errorMessage)
     {
-        super(errorType, new String[] { errorMessage });
+        super(errorMessage);
     }
-
 }
